function [Ce,Ee,Cn,En,nze,nzn] = mk_c( Nx, Ny, bnd, nze, nzn, nhor);
% creates mtx	Ce	re-computing local edges to global ones
%		Cn			   nodes

% Nx, Ny   = number of rectangular elements in x and y directions
% nze, nzn = number of non-zero edges, nodes

% C consists of G columns (G = total number of global enges/nodes) and
% 7 rows (1st row = number of local edges/nodes associated to global one,
% 2nd - 7th row = numbers of associated local edges/nodes)


iNx = Nx + 1;		% number of nodes in x
iNy = Ny + 1;		% number of nodes in y
dNx = Nx - 1;
dNy = Ny - 1;

twoNx = 2*Nx;
twoNy = 2*Ny;
thrNx = 3*Nx;
rNx   = 2*3*Nx;

		% *** E D G E S ***

Ce = sparse(3,nze); Ee = sparse(2,nzn);

b = 0;
g = 1;
for m=1:Ny		% diagonal edges
  for n=1:Nx
    b = b + 1;
    if bnd(b)~=0
      Ce(1,g) =   2;
      Ce(2,g) = + 2;	Ee(1,g) = n + twoNx*(m-1);
      Ce(3,g) = - 2;	Ee(2,g) = Ee(1,g) + Nx;
      g = g + 1;
    end
  end
end

for n=1:Nx		% 1st row of horizontal edges
  b = b + 1;
  if bnd(b)~=0
    Ce(1,g) = 1;
    Ce(2,g) = 3;	Ee(1,g) = n;
    g = g + 1;
  end
end

for m=2:Ny		% 2nd - (Ny)th row of horizontal edges
  for n=1:Nx
    b = b + 1;
    if bnd(b)~=0
      if m~=nhor(3,1)+1
        Ce(1,g) =   2;
        Ce(2,g) = + 3;	Ee(1,g) = n + twoNx*(m-1);
        Ce(3,g) = - 3;	Ee(2,g) = Ee(1,g) - Nx;
        g = g + 1;
      else
        if (n>=nhor(1,1)) & (n<=nhor(2,1))
          Ce(1,g+1) =   1;
          Ce(2,g+1) = + 3;	Ee(1,g+1) = n + twoNx*(m-1);
          Ce(1,g)   =   1;
          Ce(2,g)   = - 3;	Ee(1,g)   = Ee(1,g+1) - Nx;
          g   = g + 2;
          nze = nze + 1;
        else
          Ce(1,g) =   2;
          Ce(2,g) = + 3;	Ee(1,g) = n + twoNx*(m-1);
          Ce(3,g) = - 3;	Ee(2,g) = Ee(1,g) - Nx;
          g = g + 1;
        end
      end
    end
  end
end

for n=1:Nx		% last row of horizontal edges
  b = b + 1;
  if bnd(b)~=0
    Ce(1,g) =   1;
    Ce(2,g) = - 3;	Ee(1,g) = n + Nx*(twoNy-1);
    g = g + 1;
  end
end

for m=1:Ny		% vertical edges
  b = b + 1;
  if bnd(b)~=0
    Ce(1,g) =   1;
    Ce(2,g) = - 1;	Ee(1,g) = 1 + Nx*(2*m-1);
    g = g + 1;
  end
  for n=2:Nx
    b = b + 1;
    if bnd(b)~=0
      Ce(1,g) = 2;
      Ce(2,g) = + 1;	Ee(1,g) = n-1 + twoNx*(m-1);
      Ce(3,g) = - 1;	Ee(2,g) = Ee(1,g) + iNx;
      g = g + 1;
    end
  end
  b = b + 1;
  if bnd(b)~=0
    Ce(1,g) = 1;
    Ce(2,g) = + 1;	Ee(1,g) = (2*m-1)*Nx;
    g = g + 1;
  end
end


			% *** N O D E S ***

Cn = sparse(7,nzn); En = sparse(6,nzn);

g = 1;

b = b + 1;
if bnd(b)~=0
  Cn(1,g) = 2;
  Cn(2,g) = 1;		En(1,g) = 1;
  Cn(3,g) = 3;		En(2,g) = 1 + Nx;
  g = g + 1;
end
for n=2:Nx
  b = b + 1;
  if bnd(b)~=0
    Cn(1,g) = 3;
    Cn(2,g) = 2;	En(1,g) = n-1;
    Cn(3,g) = 1;	En(2,g) = n;
    Cn(4,g) = 3;	En(3,g) = n + Nx;
    g = g + 1;
  end
end
b = b + 1;
if bnd(b)~=0
  Cn(1,g) = 1;
  Cn(2,g) = 2;		En(1,g) = Nx;
  g = g + 1;
end

for m=2:Ny    
  b = b + 1;
  dn = (2*m-3)*Nx;
  md =  dn + Nx;
  up =  md + Nx;
  if bnd(b)~=0
      if m~=nhor(3,1)+1
        Cn(1,g) = 3;
        Cn(2,g) = 1;	En(1,g) = 1 + md;
        Cn(3,g) = 3;	En(2,g) = 1 + up;
        Cn(4,g) = 2;	En(3,g) = 1 + dn;
        g = g + 1;
      else
        if (1>=nhor(1,1)) & (1<=nhor(2,1))
          Cn(1,g) = 1;
          Cn(2,g) = 2;	En(1,g) = 1 + dn;
          g = g + 1;
          Cn(1,g) = 2;
          Cn(2,g) = 1;	En(1,g) = 1 + md;
          Cn(3,g) = 3;	En(2,g) = 1 + up;
          g   = g + 1;
          nzn = nzn + 1;
        else
          Cn(1,g) = 3;
          Cn(2,g) = 1;	En(1,g) = 1 + md;
          Cn(3,g) = 3;	En(2,g) = 1 + up;
          Cn(4,g) = 2;	En(3,g) = 1 + dn;
          g = g + 1;
        end
      end
  end
  for n=2:Nx
    b = b + 1;
    if bnd(b)~=0
      if m~=nhor(3,1)+1
        Cn(1,g) = 6;
        Cn(2,g) = 2;	En(1,g) = n-1 + md;
        Cn(3,g) = 1;	En(2,g) = n   + md;
        Cn(4,g) = 3;	En(3,g) = n   + up;
        Cn(5,g) = 2;	En(4,g) = n   + dn;
        Cn(6,g) = 1;	En(5,g) = n-1 + dn;
        Cn(7,g) = 3;	En(6,g) = n-1 + dn-Nx;
        g = g + 1;
      else
        if n>=(nhor(1,1)) & (n<=nhor(2,1))
          Cn(1,g) = 3;
          Cn(2,g) = 2;	En(1,g) = n   + dn;
          Cn(3,g) = 1;	En(2,g) = n-1 + dn;
          Cn(4,g) = 3;	En(3,g) = n-1 + dn-Nx;
          g = g + 1;
          Cn(1,g) = 3;
          Cn(2,g) = 2;	En(1,g) = n-1 + md;
          Cn(3,g) = 1;	En(2,g) = n   + md;
          Cn(4,g) = 3;	En(3,g) = n   + up;
          g = g + 1;
          nzn = nzn + 1;
        else
          Cn(1,g) = 6;
          Cn(2,g) = 2;	En(1,g) = n-1 + md;
          Cn(3,g) = 1;	En(2,g) = n   + md;
          Cn(4,g) = 3;	En(3,g) = n   + up;
          Cn(5,g) = 2;	En(4,g) = n   + dn;
          Cn(6,g) = 1;	En(5,g) = n-1 + dn;
          Cn(7,g) = 3;	En(6,g) = n-1 + dn-Nx;
          g = g + 1;
        end
      end
    end
  end
  b = b + 1;
  if bnd(b)~=0
    Cn(1,g) = 3;
    Cn(2,g) = 2;	En(1,g) = up;
    Cn(3,g) = 1;	En(2,g) = md;
    Cn(4,g) = 3;        En(3,g) = dn;
    g = g + 1;
  end
end

b = b + 1;
if bnd(b)~=0
  Cn(1,g) = 1;
  Cn(2,g) = 2;		En(1,g) = 1 + (2*Ny-1)*Nx;
  g = g + 1;
end
for n=2:Nx
  b = b + 1;
  if bnd(b)~=0
    Cn(1,g) = 3;
    Cn(2,g) = 2;	En(1,g) = n   + (2*Ny-1)*Nx;
    Cn(3,g) = 1;	En(2,g) = n-1 + (2*Ny-1)*Nx;
    Cn(4,g) = 3;	En(3,g) = n-1 + 2*(Ny-1)*Nx;
    g = g + 1;
  end
end
b = b + 1;
if bnd(b)~=0
  Cn(1,g) = 2;
  Cn(2,g) = 3;		En(1,g) = (2*Ny-1)*Nx;
  Cn(3,g) = 1;		En(2,g) = 2*Ny*Nx;
  g = g + 1;
end